@@ -19,7 +19,7 @@
 #define KNEWSTUFF3_KNEWSTUFFENTRY_P_H
 
 #include <QtCore/QStringList>
-#include "core/entryinternal_p.h"
+#include "core/entryinternal.h"
 
 namespace KNS3
 {
@@ -27,7 +27,13 @@ namespace KNS3
 class EntryPrivate : public QSharedData
 {
 public:
-    EntryInternal e;
+    KNSCore::EntryInternal e;
+    static Entry fromInternal(const KNSCore::EntryInternal* internal)
+    {
+        Entry e;
+        e.d->e = *internal;
+        return e;
+    }
 };
 }
 
